<?php
namespace ONM\RedirectLinkhandling\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Backend Action Controller for the redirectlinkhandlingmod
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class LinkhandlingController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * linkRepository
	 *
	 * @var \ONM\RedirectLinkhandling\Domain\Repository\LinkRepository
         * @inject
	 */
	protected $linkRepository;

	/**
	 * ruleRepository
	 *
	 * @var \ONM\RedirectLinkhandling\Domain\Repository\RuleRepository
         * @inject
	 */
	protected $ruleRepository;

	/**
	 * standard default action
         * test urls and see which rule or link handles it
	 *
	 * @return void
	 */
	public function standardAction() {
        // get form data
            $args = $this->request->getArguments();
            if (isset($args['url']) && $args['url'] != '') {
            // form to test urls was submitted
            // create Linkhandler object, in this case we don't care about any storage pids
            $linkHandler = new \ONM\RedirectLinkhandling\Handler\LinkHandler($args['url']);
            $alh = $linkHandler->getLinkHandlingArray();
            switch ($alh[0]) {
                case \ONM\RedirectLinkhandling\Handler\LinkHandler::REDIRECT_TO_404:
                    $status = "TYPO3 will return a 404 http status and redirect to the error page";
                    break;
                case \ONM\RedirectLinkhandling\Handler\LinkHandler::REDIRECT_TO_TARGET:
                    $status = "TYPO3 will redirect and return the status 301";
                    break;
                case \ONM\RedirectLinkhandling\Handler\LinkHandler::NEW_URL:
                    $status = "This link is currently not handled by redirect linkhandling";
                    break;

            }
            $this->view->assign('url', $args['url']);
            $this->view->assign('status', $status);
            $this->view->assign('target', \ONM\RedirectLinkhandling\Utility\Div::getUrl($alh[1]));
            // linkhandler stores information about the rule or link which matched against the last given url in the property lastHit
            $lastHit = $linkHandler->getLastHit();
            $this->view->assign($lastHit[0], $lastHit[1]);
		} else {
			if (isset($args['submitUrl'])) {
				// no url given, but submitUrl clicked
				$this->flashMessageContainer->add('You have clicked submit but no text was entered.', '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			}
		}
	}
}
