<?php
namespace ONM\RedirectLinkhandling\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Link extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

    /**
     * uid
     *
     * @var int
     */
    protected $uid;

    /**
     * the request uri
     *
     * @var string
     * @validate NotEmpty
     */
    protected $uri;

    /**
     * the target link or pid
     *
     * @var string
     */
    protected $target;

    /**
     * has this link already been handled by an admin
     *
     * @var boolean
     */
    protected $handled = FALSE;

    /**
     * admin already notified
     *
     * @var boolean
     */
    protected $sent = FALSE;

    /**
     * you can hide entries through the backend
     *
     * @var boolean
     */
    protected $hidden = FALSE;

    /**
     * counter for every Hit
     *
     * @var int
     */
    protected $hitcounter = 0;

    /**
     * Returns the uri
     *
     * @return string $uri
     */
    public function getUri() {
            return $this->uri;
    }

    /**
     * Sets the uri
     *
     * @param string $uri
     * @return void
     */
    public function setUri($uri) {
            $this->uri = $uri;
    }

    /**
     * Returns the target
     *
     * @return string $target
     */
    public function getTarget() {
            return $this->target;
    }

    /**
     * Sets the target
     *
     * @param string $target
     * @return void
     */
    public function setTarget($target) {
            $this->target = $target;
    }

    /**
     * Returns the handled
     *
     * @return boolean $handled
     */
    public function getHandled() {
            return $this->handled;
    }

    /**
     * Sets the nohandling
     *
     * @param boolean $handled
     * @return void
     */
    public function setHandled($handled) {
            $this->handled = $handled;
    }

    /**
     * Returns the boolean state of handled
     *
     * @return boolean
     */
    public function isHandled() {
            return $this->getHandled();
    }

    /**
     * Returns the sent
     *
     * @return boolean $sent
     */
    public function getSent() {
            return $this->sent;
    }

    /**
     * Sets the sent
     *
     * @param boolean $sent
     * @return void
     */
    public function setSent($sent) {
            $this->sent = $sent;
    }

    /**
     * Returns the boolean state of sent
     *
     * @return boolean
     */
    public function isSent() {
            return $this->getSent();
    }

    /**
     * Returns the hidden
     *
     * @return boolean $hidden
     */
    public function getHidden() {
            return $this->hidden;
    }

    /**
     * Sets the hidden
     *
     * @param boolean $hidden
     * @return void
     */
    public function setHidden($hidden) {
            $this->hidden = $hidden;
    }

    /**
     * Returns the boolean state of hidden
     *
     * @return boolean
     */
    public function isHidden() {
            return $this->getHidden();
    }

    /**
     * Returns the hitcounter
     *
     * @return int $hitcounter
     */
    public function getHitcounter() {
            return $this->hitcounter;
    }

    /**
     * Sets the hitcounter
     *
     * @param int $hitcounter
     * @return void
     */
    public function setHitcounter($hitcounter) {
            $this->hitcounter = $hitcounter;
    }

    /**
     * Increase the hitcounter
     *
     * @return void
     */
    public function increaseHitcounter() {
            $this->hitcounter++;
    }
}