<?php
namespace ONM\RedirectLinkhandling\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Rule extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

    /**
     * uid
     *
     * @var int
     */
    protected $uid;

    /**
     * regular expression
     *
     * @var string
     * @validate NotEmpty
     */
    protected $expression;

    /**
     * the target link or pid
     *
     * @var string
     */
    protected $target;

    /**
     * active
     *
     * @var boolean
     */
    protected $active = FALSE;

    /**
     * ignoreonredirect
     *
     * @var boolean
     */
    protected $ignoreonredirect = FALSE;

    /**
     * counter for every Hit
     *
     * @var int
     */
    protected $hitcounter = 0;

    /**
     * Returns the expression
     *
     * @return string $expression
     */
    public function getExpression() {
            return $this->expression;
    }

    /**
     * Sets the expression
     *
     * @param string $expression
     * @return void
     */
    public function setExpression($expression) {
            $this->expression = $expression;
    }

    /**
     * Returns the target
     *
     * @return string $target
     */
    public function getTarget() {
            return $this->target;
    }

    /**
     * Sets the target
     *
     * @param string $target
     * @return void
     */
    public function setTarget($target) {
            $this->target = $target;
    }

    /**
     * Returns the active
     *
     * @return boolean $active
     */
    public function getActive() {
            return $this->active;
    }

    /**
     * Sets the active
     *
     * @param boolean $active
     * @return void
     */
    public function setActive($active) {
            $this->active = $active;
    }

    /**
     * returns the state of the boolen of active
     *
     * @return boolean
     */
    public function isActive() {
            return $this->getActive();
    }

    /**
     * Returns the ignoreonredirect
     *
     * @return boolean $ignoreonredirect
     */
    public function getIgnoreonredirect() {
            return $this->ignoreonredirect;
    }

    /**
     * Sets the ignoreonredirect
     *
     * @param boolean $ignoreonredirect
     * @return void
     */
    public function setIgnoreonredirect($ignoreonredirect) {
            $this->ignoreonredirect = $ignoreonredirect;
    }

    /**
     * returns the state of the boolen of ignoreonredirect
     *
     * @param boolean $ignoreonredirect
     * @return void
     */
    public function isIgnoreonredirect() {
            return $this->getIgnoreonredirect();
    }

    /**
     * Returns the hitcounter
     *
     * @return int $hitcounter
     */
    public function getHitcounter() {
            return $this->hitcounter;
    }

    /**
     * Sets the hitcounter
     *
     * @param int $hitcounter
     * @return void
     */
    public function setHitcounter($hitcounter) {
            $this->hitcounter = $hitcounter;
    }

    /**
     * Increase the hitcounter
     *
     * @return void
     */
    public function increaseHitcounter() {
            $this->hitcounter++;
    }
}