<?php
namespace ONM\RedirectLinkhandling\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class LinkRepository extends \ONM\RedirectLinkhandling\Domain\Repository\AbstractRepository {

       public function initializeObject() {
           
          $querySettings = $this->objectManager->get('\\TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');
          $querySettings->setIgnoreEnableFields(TRUE);
          $querySettings->setIncludeDeleted(TRUE);
       }
       
	/**
	 * return one entry with given uri or NULL if not found
	 *
	 * @param string $uri
	 * @return \ONM\RedirectLinkhandling\Domain\Model\Link
	 */
	public function findByUri($uri) {
            $query = $this->createQuery();
            // we also want to get hidden entries
            // you shouldn't hide links, but in case someone does, it is better to avoid double entries of uri
            $object = $query->matching(
                            $query->equals('uri', $uri)
                          )
                        ->execute()
                        ->getFirst();
            return $object;
	}
        
        /**
	 * return all entries which are older than $days days, not handled and where the hitcounter is smaller than $numberOfMaxHits
	 *
	 * @param int $days
         * @param int $numberOfMaxHits
	 * @return \TYPO3\CMS\Extbase\Persistence\QueryResultInterface|array The query result
	 */
	public function findOld($days, $numberOfMaxHits, $limit = 10000) {
            $dateTime = new \DateTime('today - ' . strval($days) . ' days');
            $query = $this->createQuery();
            $objects = $query
                        ->matching(
                            $query->logicalAnd(
                                $query->lessThan('hitcounter', $numberOfMaxHits),
                                $query->equals('handled', 0),
                                $query->lessThan('crdate', $dateTime->format('U'))
                            )
                          )
                        ->setLimit($limit)
                        ->execute();
            return $objects;
	}
}