<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * PageNotFoundHandler
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */

class user_PageNotFound {
    /**
     * this function should be called on every 404 handled by TYPO3
     *
     * @param array $param
     * @param array $ref
     */
    public function main($param, $ref) {
        // complete requested url
    	$url = t3lib_div::getIndpEnv('TYPO3_REQUEST_URL');
    	// host is needed for multidomain environments
        $domain = t3lib_div::getIndpEnv('HTTP_HOST');
        // default storage pid is the root
        $storagePids = array(0);
        // we want to find only those rules and links which are needed for our domain rootline
        // that means we need to get the correct storagePids
        $tsconfig = Tx_RedirectLinkhandling_Utility_Div::generateTSConfig($domain);
        $sp = Tx_RedirectLinkhandling_Utility_Div::getExtTSConfigValue($tsconfig, 'storagePid', 'persistence');
        if ($sp) {
            // storage pids can be configured via typoscript
            $storagePids = explode(',', $sp);
        }
        // we need to have the TYPO3 Frontend Array for extensions like simulatic_static or realUrl to work with the linkbuilding module of TYPO3
        Tx_RedirectLinkhandling_Utility_Div::initTSFE(Tx_RedirectLinkhandling_Utility_Div::getRootline($domain));
        // finally start linkhandling
        $linkHandler = new Tx_RedirectLinkhandling_Handler_LinkHandler($url);
        $linkHandler->setDomain($domain);
        $linkHandler->setStoragePids($storagePids);
        $arr_handling = $linkHandler->getLinkHandlingArray();
        switch($arr_handling[0]) {
            case Tx_RedirectLinkhandling_Handler_LinkHandler::REDIRECT_TO_404:
                // count hit and redirect
                $linkHandler->countHit();
                Tx_RedirectLinkhandling_Utility_Div::redirect($this->getErrorPage($tsconfig), t3lib_utility_Http::HTTP_STATUS_404);
                break;
            case Tx_RedirectLinkhandling_Handler_LinkHandler::REDIRECT_TO_TARGET:
                // count hit and redirect
                $linkHandler->countHit();
                Tx_RedirectLinkhandling_Utility_Div::redirect($arr_handling[1], t3lib_utility_Http::HTTP_STATUS_301);
                break;
            case Tx_RedirectLinkhandling_Handler_LinkHandler::NEW_URL:
                // store link in database and redirect
                $linkHandler->storeLink();
                Tx_RedirectLinkhandling_Utility_Div::redirect($this->getErrorPage($tsconfig), t3lib_utility_Http::HTTP_STATUS_404);
        }
    }

    /**
     * get Error page (normally it is an id but a relative or absolute url is also accepted in case you want to use a static html error page
     *
     * @param t3lib_tsparser_ext $tsconfig
     * @return string
     */
    protected function getErrorPage($tsconfig) {
        return Tx_RedirectLinkhandling_Utility_Div::getExtTSConfigValue($tsconfig, 'errorPage');
    }
}

?>
