<?php
namespace ONM\RedirectLinkhandling\Utility;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * helper functions
 *
 * @package redirect_linkhandling
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Div {

    /**
     * redirect to target page or 404 page and exit
     *
     * @param string $target url of the target or uid of the target page
     * @param int $http_status mostly 301 or 404
     */
    public static function redirect($target, $http_status) {

        \TYPO3\CMS\Core\Utility\HttpUtility::redirect(self::getUrl($target), $http_status);
    	exit;
    }

    /**
     * build url with the help of the TYPO3 core so extension like simulatestatic and realUrl can work
     *
     * @param string $target
     * @return string
     */
    public static function getUrl($target, $absolute = FALSE) {
        // we need to have the TYPO3 Frontend Array
        //if (!$GLOBALS['TSFE']) {
            self::initTSFE($target);
        //}
        // we want to let TYPO3 handle linkbuilding
        $cObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer');
        $params = array(
            'parameter' 	=> $target
        );
        
        if ($absolute) {
            $params['forceAbsoluteUrl'] = 1;
            if (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') {
                $params['forceAbsoluteUrl.'] = array( 'scheme' => 'https' );
            }
        }
        return $cObj->typoLink_URL($params);
    }

    /**
     * returns the TS configuration array of this extension due to the correct rootline
     *
     * @param string $value
     * @param string $domain
     * @param \TYPO3\CMS\Core\TypoScript\TemplateService $tsconfig
     * @param string $cat
     * @return string typoscript code
     */
    public static function getExtTSConfigValue($tsconfig, $value, $cat = 'settings') {
        try {
            $result = $tsconfig->setup['module.']['tx_redirectlinkhandling.'][$cat . '.'][$value];
            return $result;
        } catch (Exception $e) {
            \ONM\RedirectLinkhandling\Utility\Div::log($e->getMessage());
            return NULL;
        }
    }

    /**
     * get typoscript configuration depending on the tree
     *
     * @param string	$domain	url
     * @return	\TYPO3\CMS\Core\TypoScript\TemplateService
     */
    public static function generateTSConfig($domain) {
    	$rootLine = \ONM\RedirectLinkhandling\Utility\Div::getRootLine($domain);
        $tsConfig = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Core\\TypoScript\\TemplateService');
        $tsConfig->tt_track = 0;
        $tsConfig->init();
        $tsConfig->runThroughTemplates($rootLine, 0);
        $tsConfig->generateConfig();
        return $tsConfig;
    }

    /**
     * get rootline depending on domain url
     * if this is not a multidomain installation, the rootPid will be 1
     *
     * @param string	$domain url
     * @return array	rootline
     */
    public static function getRootline($domain) {
        $page = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Frontend\\Page\\PageRepository');
        $rootPid = self::getRootPageId($domain);
        return $page->getRootline($rootPid);
   	}

    public static function getRootPageId($domain=NULL) {
        if ($domain) {
            $page = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Frontend\\Page\\PageRepository');
            $rootPid = $page->getDomainStartPage($domain);
        }
        if (!$rootPid) {
            $rows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('pid',
                        'sys_template', 'root=1 AND hidden=0 AND deleted=0');
            if (count($rows) >= 1) {
                    $rootPid = $rows[0]['pid'];
            }
        }

        if (!$rootPid) {
            $rootPid = 1;
        }
        return $rootPid;
    }

	/**
	 * init TSFE
	 *
	 * @param $pageUid	int		uid of the root page
	 */
    public static function initTSFE($pageUid=NULL) {
        if (!$pageUid) {
            $pageUid = self::getRootPageId();
        }
        if (!is_object($GLOBALS['TT'])) {
            $GLOBALS['TT'] = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Core\\TimeTracker\\TimeTracker');
            $GLOBALS['TT']->start();
        }
        if (!is_object($GLOBALS['TSFE'])) {
            $GLOBALS['TSFE'] = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Frontend\\Controller\\TypoScriptFrontendController', $GLOBALS['TYPO3_CONF_VARS'], $pageUid, 0);
        } else {
            $GLOBALS['TSFE']->id=$pageUid;
            $GLOBALS['TSFE']->type=0;
        }
        if (!$GLOBALS['TSFE']->sys_page) {
            // sys_page needs to be instanciated for Tx_Extbase_Persistence_Storage_Typo3DbBackend
            $GLOBALS['TSFE']->sys_page = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('\\TYPO3\\CMS\\Frontend\\Page\\PageRepository');
            $GLOBALS['TSFE']->sys_page->init(true);
        }
        $GLOBALS['TSFE']->initTemplate();
        $GLOBALS['TSFE']->rootLine = $GLOBALS['TSFE']->sys_page->getRootLine($pageUid, '');
        $GLOBALS['TSFE']->getConfigArray();
    }
    public static function outputURLAs404($target)
    {
        $url = self::getUrl($target, TRUE);
        $c = curl_init();
        curl_setopt($c, CURLOPT_URL, $url);
        curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($c, CURLOPT_HEADER, 0);
        $result = curl_exec($c);
        curl_close($c);
        \TYPO3\CMS\Core\Utility\HttpUtility::setResponseCode(\TYPO3\CMS\Core\Utility\HttpUtility::HTTP_STATUS_404);
        echo $result; 
        exit;
    }
}
?>
