<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 David Mann <dm@onm.de>, Open New Media GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Test case for class Tx_RedirectLinkhandling_Domain_Model_Link.
 *
 * @version $Id$
 * @copyright Copyright belongs to the respective authors
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 * @package TYPO3
 * @subpackage Redirect Linkhandling
 *
 * @author David Mann <dm@onm.de>
 */
class Tx_RedirectLinkhandling_Domain_Model_LinkTest extends Tx_Extbase_Tests_Unit_BaseTestCase {
	/**
	 * @var Tx_RedirectLinkhandling_Domain_Model_Link
	 */
	protected $fixture;

	public function setUp() {
		$this->fixture = new Tx_RedirectLinkhandling_Domain_Model_Link();
	}

	public function tearDown() {
		unset($this->fixture);
	}

	/**
	 * @test
	 */
	public function getUriReturnsInitialValueForString() {
		$this->assertNull($this->fixture->getTarget());
    }

	/**
	 * @test
	 */
	public function setUriForStringSetsUri() {
		$this->fixture->setUri('This is a unit test');

		$this->assertSame(
			'This is a unit test',
			$this->fixture->getUri()
		);
	}

	/**
	 * @test
	 */
	public function getTargetReturnsInitialValueForString() {
		$this->assertNull($this->fixture->getTarget());
    }

	/**
	 * @test
	 */
	public function setTargetForStringSetsTarget() {
		$this->fixture->setTarget('This is a unit test');

		$this->assertSame(
			'This is a unit test',
			$this->fixture->getTarget()
		);
	}

	/**
	 * @test
	 */
	public function getHandledReturnsInitialValueForBoolean() {
		$this->assertFalse($this->fixture->getHandled());
	}

	/**
	 * @test
	 */
	public function setHandledForBooleanSetsHandled() {
		$this->fixture->setHandled(TRUE);

		$this->assertTrue($this->fixture->getHandled());
	}

	/**
	 * @test
	 */
	public function isHandledForBooleanHandled() {
		$this->fixture->setHandled(TRUE);

		$this->assertTrue($this->fixture->isHandled());
	}

	/**
	 * @test
	 */
	public function getSentReturnsInitialValueForBoolean() {
		$this->assertFalse($this->fixture->getSent());
    }

	/**
	 * @test
	 */
	public function setSentForBooleanSetsSent() {
		$this->fixture->setSent(TRUE);

		$this->assertTrue($this->fixture->getSent());
	}

	/**
	 * @test
	 */
	public function isSentForBooleanSent() {
		$this->fixture->setSent(TRUE);

		$this->assertTrue($this->fixture->isSent());
	}

	/**
	 * @test
	 */
	public function getHiddenReturnsInitialValueForBoolean() {
		$this->assertFalse($this->fixture->getHidden());
    }

	/**
	 * @test
	 */
	public function setHiddenForBooleanSetsHidden() {
		$this->fixture->setHidden(TRUE);

		$this->assertTrue($this->fixture->getHidden());
	}

	/**
	 * @test
	 */
	public function isHiddenForBooleanHidden() {
		$this->fixture->setHidden(TRUE);

		$this->assertTrue($this->fixture->isHidden());
	}

	/**
	 * @test
	 */
	public function getHitcounterReturnsInitialValueForInt() {
		$this->assertEquals(
			0,
			$this->fixture->getHitcounter()
		);
    }

	/**
	 * @test
	 */
	public function setHitcounterForBooleanSetsHitcounter() {
		$this->fixture->setHitcounter(3);

		$this->assertEquals(
			3,
			$this->fixture->gethitcounter()
		);
	}

	/**
	 * @test
	 */
	public function increaseHitcounterForIntHitcounter() {
        $cnt = $this->fixture->getHitcounter();
        $cnt++;
        $this->fixture->increaseHitcounter();
		$this->assertEquals(
			$cnt,
			$this->fixture->getHitcounter()
		);
    }
}
?>